package Bundle::Tie::DB_File::SplitHash;

$VERSION = '1.01';

1;

__END__

=head1 NAME

Bundle::Tie::DB_File::SplitHash - A bundle to install all Tie::DB_File::SplitHash related modules

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Tie::DB_File::SplitHash'>

=head1 CONTENTS

Digest::MD5             - For repeatable 'random numbers' 

Tie::DB_File::SplitHash - The Tie::DB_File::SplitHash module itself

=head1 DESCRIPTION

This bundle includes the Tie::DB_File::SplitHash module and all modules
that it depends on.

=head1 AUTHOR

Benjamin Franz E<lt>F<snowhare@nihongo.org>E<gt>

=cut
